/// <reference types="node" />
import { CrossChainUpdateTransactionParams, LastCertificate } from 'lisk-sdk';
import { ChainConnectorDB } from './db';
import { ChainAPIClient } from './chain_api_client';
import { LastSentCCM, Logger, ModuleMetadata } from './types';
interface ComputeCCUConfig {
    registrationHeight: number;
    ownChainID: Buffer;
    receivingChainID: Buffer;
    maxCCUSize: number;
    ccuFee: string;
    isSaveCCU: boolean;
}
interface ComputeCCUInitArgs {
    logger: Logger;
    db: ChainConnectorDB;
    sendingChainAPIClient: ChainAPIClient;
    receivingChainAPIClient: ChainAPIClient;
    lastCertificate: LastCertificate;
    interoperabilityMetadata: ModuleMetadata;
}
export declare class CCUHandler {
    private readonly _registrationHeight;
    private readonly _ownChainID;
    private readonly _receivingChainID;
    private readonly _maxCCUSize;
    private readonly _isReceivingChainMainchain;
    private readonly _isSaveCCU;
    private readonly _ccuFee;
    private _db;
    private _logger;
    private _sendingChainAPIClient;
    private _receivingChainAPIClient;
    private _lastCertificate;
    private _interoperabilityMetadata;
    private _outboxKeyForInclusionProof;
    constructor(config: ComputeCCUConfig);
    load(args: ComputeCCUInitArgs): void;
    computeCCU(lastCertificate: LastCertificate, lastIncludedCCM?: LastSentCCM): Promise<{
        ccuParams: CrossChainUpdateTransactionParams;
        lastCCMToBeSent: LastSentCCM | undefined;
    } | undefined>;
    submitCCU(ccuParams: CrossChainUpdateTransactionParams, lastSentCCUTxID: string): Promise<string | undefined>;
    private _findCertificate;
    private _getCcuFee;
}
export {};
