/// <reference types="node" />
import { BFTHeights, ChainAccount, ChannelData, EventCallback, apiClient, TransactionJSON } from 'lisk-sdk';
import { BFTParametersWithoutGeneratorKey, Logger, NodeInfo } from './types';
interface APIConfig {
    wsConnectionString?: string;
    ipcPath?: string;
    logger: Logger;
}
export declare class ChainAPIClient {
    chainID: Buffer;
    private readonly _config;
    private _client;
    constructor(config: APIConfig);
    connect(client?: apiClient.APIClient): Promise<void>;
    disconnect(): Promise<void>;
    subscribe(eventName: string, cb: EventCallback): void;
    postTransaction(txBytes: Buffer): Promise<{
        transactionId: string;
    }>;
    getTransactionByID(id: string): Promise<TransactionJSON>;
    getAuthAccountNonceFromPublicKey(publicKey: Buffer): Promise<string>;
    getNodeInfo(): Promise<NodeInfo>;
    getChannelAccount(chainID: Buffer): Promise<ChannelData | undefined>;
    getChainAccount(chainID: Buffer): Promise<ChainAccount | undefined>;
    hasUserTokenAccount(userAddress: string): Promise<{
        exists: boolean;
    }>;
    getTokenInitializationFee(): Promise<{
        userAccount: string;
        escrowAccount: string;
    }>;
    getBFTHeights(): Promise<BFTHeights>;
    getEvents(height: number): Promise<{
        module: string;
        name: string;
        topics: string[];
        index: number;
        height: number;
        data: string;
    }[]>;
    getMetadataByModuleName(moduleName: string): Promise<import("./types").ModuleMetadata>;
    getInclusionProof(queryKeys: Buffer[]): Promise<import("lisk-sdk").ProveResponse>;
    getSavedInclusionProofAtHeight(height: number): Promise<import("lisk-sdk").ProveResponse>;
    getBFTParametersAtHeight(height: number): Promise<BFTParametersWithoutGeneratorKey>;
}
export {};
