import { BasePlugin, PluginInitContext } from 'lisk-sdk';
import { ChainConnectorPluginConfig } from './types';
import { ChainConnectorEndpoint } from './endpoint';
export declare class ChainConnectorPlugin extends BasePlugin<ChainConnectorPluginConfig> {
    readonly endpoint: ChainConnectorEndpoint;
    configSchema: {
        $id: string;
        type: string;
        properties: {
            receivingChainIPCPath: {
                type: string;
                description: string;
            };
            receivingChainWsURL: {
                type: string;
                description: string;
            };
            ccuFrequency: {
                type: string;
                description: string;
            };
            encryptedPrivateKey: {
                type: string;
                description: string;
            };
            ccuFee: {
                type: string;
                format: string;
                description: string;
            };
            isSaveCCU: {
                type: string;
                description: string;
            };
            maxCCUSize: {
                type: string;
                description: string;
                minimum: number;
                maximum: number;
            };
            ccuSaveLimit: {
                type: string;
                description: string;
                minimum: number;
            };
            registrationHeight: {
                type: string;
                description: string;
                minimum: number;
            };
            receivingChainID: {
                type: string;
                description: string;
            };
        };
        required: string[];
        default: {
            ccuFrequency: number;
            isSaveCCU: boolean;
            ccuFee: string;
            maxCCUSize: number;
            registrationHeight: number;
            ccuSaveLimit: number;
        };
    };
    private readonly _chainConnectorDB;
    private _receivingChainClient;
    private _sendingChainClient;
    private _ownChainID;
    private _receivingChainID;
    private _blockEventHandler;
    get nodeModulePath(): string;
    init(context: PluginInitContext): Promise<void>;
    load(): Promise<void>;
    unload(): Promise<void>;
}
