/// <reference types="node" />
import { db as liskDB, AggregateCommit, chain, CCMsg } from 'lisk-sdk';
import { BlockHeader, CCMWithHeight, LastSentCCM, ValidatorsDataWithHeight } from './types';
type KVStore = liskDB.Database;
export declare const getDBInstance: (dataPath: string, dbName?: string) => Promise<KVStore>;
export declare const checkDBError: (error: Error | unknown) => void;
export declare const concatDBKeys: (...keys: Buffer[]) => Buffer;
export declare const uint32BE: (val: number) => Buffer;
export declare class ChainConnectorDB {
    private _db;
    private _privateKey?;
    load(dataPath: string): Promise<void>;
    close(): void;
    get privateKey(): Buffer | undefined;
    saveToDBOnNewBlock(blockHeader: BlockHeader): Promise<void>;
    getBlockHeaderByHeight(height: number): Promise<BlockHeader | undefined>;
    getBlockHeadersBetweenHeights(fromHeight: number, toHeight: number): Promise<BlockHeader[]>;
    deleteBlockHeadersBetweenHeight(fromHeight: number, toHeight: number): Promise<void>;
    deleteBlockHeaderByHeight(height: number): Promise<void>;
    getAggregateCommitByHeight(height: number): Promise<AggregateCommit | undefined>;
    getAggregateCommitBetweenHeights(fromHeight: number, toHeight: number): Promise<AggregateCommit[]>;
    deleteAggregateCommitsBetweenHeight(fromHeight: number, toHeight: number): Promise<void>;
    deleteAggregateCommitByHeight(height: number): Promise<void>;
    getValidatorsDataByHash(validatorsHash: Buffer): Promise<ValidatorsDataWithHeight | undefined>;
    setValidatorsDataByHash(validatorsHash: Buffer, validatorsData: ValidatorsDataWithHeight, height: number): Promise<void>;
    getValidatorsDataByHeight(height: number): Promise<ValidatorsDataWithHeight | undefined>;
    deleteValidatorsHashByHeight(height: number): Promise<void>;
    deleteValidatorsHashBetweenHeights(fromHeight: number, toHeight: number): Promise<void>;
    deleteValidatorsDataByHash(validatorsHash: Buffer): Promise<void>;
    getAllValidatorsData(): Promise<ValidatorsDataWithHeight[]>;
    getCCMsByHeight(height: number): Promise<CCMsg[]>;
    deleteCCMsByHeight(height: number): Promise<void>;
    getCCMsBetweenHeights(fromHeight: number, toHeight: number): Promise<CCMWithHeight[]>;
    deleteCCMsBetweenHeight(fromHeight: number, toHeight: number): Promise<void>;
    setCCMsByHeight(ccms: CCMWithHeight[], height: number): Promise<void>;
    getLastSentCCM(): Promise<LastSentCCM | undefined>;
    setLastSentCCM(ccm: LastSentCCM): Promise<void>;
    getListOfCCUs(): Promise<{
        list: Record<string, unknown>[];
        total: number;
    }>;
    setCCUTransaction(ccu: chain.TransactionAttrs): Promise<void>;
    deleteCCUTransaction(ccuID: Buffer): Promise<void>;
    setPrivateKey(encryptedPrivateKey: string, password: string): Promise<void>;
    deletePrivateKey(encryptedPrivateKey: string, password: string): Promise<void>;
}
export {};
