"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChainConnectorEndpoint = void 0;
const lisk_sdk_1 = require("lisk-sdk");
const utils_1 = require("./utils");
const schemas_1 = require("./schemas");
const validator = lisk_sdk_1.validator.validator;
class ChainConnectorEndpoint extends lisk_sdk_1.BasePluginEndpoint {
    load(encryptedPrivateKey, store) {
        this._encryptedPrivateKey = encryptedPrivateKey;
        this.db = store;
    }
    async getSentCCUs(_context) {
        return this.db.getListOfCCUs();
    }
    async getAggregateCommits(context) {
        const { from, to } = context.params;
        const aggregateCommits = await this.db.getAggregateCommitBetweenHeights(from, to);
        return aggregateCommits.map(aggregateCommit => (0, utils_1.aggregateCommitToJSON)(aggregateCommit));
    }
    async getBlockHeaders(context) {
        const { from, to } = context.params;
        const blockHeaders = await this.db.getBlockHeadersBetweenHeights(from, to);
        return blockHeaders.map(blockHeader => new lisk_sdk_1.BlockHeader(blockHeader).toJSON());
    }
    async getCrossChainMessages(context) {
        const { from, to } = context.params;
        const ccms = await this.db.getCCMsBetweenHeights(from, to);
        return (0, utils_1.ccmsWithHeightToJSON)(ccms);
    }
    async getLastSentCCM(_context) {
        const lastSentCCM = await this.db.getLastSentCCM();
        if (!lastSentCCM) {
            throw new Error('No CCM was sent so far.');
        }
        return {
            ...lastSentCCM,
            fee: lastSentCCM.fee.toString(),
            height: lastSentCCM.height,
            receivingChainID: lastSentCCM.receivingChainID.toString('hex'),
            sendingChainID: lastSentCCM.sendingChainID.toString('hex'),
            nonce: lastSentCCM.nonce.toString(),
            params: lastSentCCM.params.toString('hex'),
        };
    }
    async getAllValidatorsData(_context) {
        const validatorsHashPreimage = await this.db.getAllValidatorsData();
        return (0, utils_1.validatorsHashPreimagetoJSON)(validatorsHashPreimage);
    }
    async authorize(context) {
        validator.validate(schemas_1.authorizeRequestSchema, context.params);
        const { enable, password } = context.params;
        const result = `Successfully ${enable ? 'enabled' : 'disabled'} the chain connector plugin.`;
        if (!enable) {
            await this.db.deletePrivateKey(this._encryptedPrivateKey, password);
            return {
                result,
            };
        }
        await this.db.setPrivateKey(this._encryptedPrivateKey, password);
        return {
            result,
        };
    }
}
exports.ChainConnectorEndpoint = ChainConnectorEndpoint;
//# sourceMappingURL=endpoint.js.map