"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.calculateMessageWitnesses = void 0;
const lisk_sdk_1 = require("lisk-sdk");
const calculateMessageWitnesses = (inboxSizeOnReceivingChain, outboxSizeOnSendingChain, lastSentCCM, ccmsToBeIncluded, maxCCUSize) => {
    const allSerializedCCMs = [];
    const includedSerializedCCMs = [];
    let lastCCMWithHeight;
    let totalSize = 0;
    for (const ccm of ccmsToBeIncluded) {
        if (ccm.height !== 0 && lastSentCCM.height === ccm.height && ccm.nonce === lastSentCCM.nonce) {
            continue;
        }
        if (inboxSizeOnReceivingChain < outboxSizeOnSendingChain) {
            const ccmBytes = lisk_sdk_1.codec.encode(lisk_sdk_1.ccmSchema, ccm);
            totalSize += ccmBytes.length;
            if (totalSize < maxCCUSize) {
                includedSerializedCCMs.push(ccmBytes);
                lastCCMWithHeight = { ...ccm, height: ccm.height };
            }
            allSerializedCCMs.push(ccmBytes);
        }
    }
    if (includedSerializedCCMs.length < 1) {
        return {
            crossChainMessages: [],
            messageWitnessHashes: [],
            lastCCMToBeSent: undefined,
        };
    }
    if (includedSerializedCCMs.length === allSerializedCCMs.length) {
        return {
            crossChainMessages: includedSerializedCCMs,
            messageWitnessHashes: [],
            lastCCMToBeSent: {
                ...lastCCMWithHeight,
                outboxSize: outboxSizeOnSendingChain,
            },
        };
    }
    const remainingSerializedCCMs = allSerializedCCMs.slice(includedSerializedCCMs.length);
    const messageWitnessHashes = lisk_sdk_1.tree.regularMerkleTree.calculateRightWitness(inboxSizeOnReceivingChain + includedSerializedCCMs.length, remainingSerializedCCMs);
    return {
        crossChainMessages: includedSerializedCCMs,
        messageWitnessHashes,
        lastCCMToBeSent: {
            ...lastCCMWithHeight,
            outboxSize: outboxSizeOnSendingChain,
        },
    };
};
exports.calculateMessageWitnesses = calculateMessageWitnesses;
//# sourceMappingURL=inbox_update.js.map